@@ -1,7 +1,7 @@
 package File::Slurper::Temp;
 
 our $DATE = '2017-01-16'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -16,7 +16,7 @@ our @EXPORT_OK = qw(write_text write_binary);
 sub write_text {
     my $filename = shift;
 
-    my ($tempname, $tempfh) = File::Temp::tempfile();
+    my ($tempfh, $tempname) = File::Temp::tempfile();
     File::Slurper::write_text($tempname, @_);
     rename $tempname, $filename
         or croak "Couldn't rename $tempname to $filename: $!";
@@ -42,7 +42,7 @@ File::Slurper::Temp - File::Slurper + File::Temp
 
 =head1 VERSION
 
-This document describes version 0.002 of File::Slurper::Temp (from Perl distribution File-Slurper-Temp), released on 2017-01-16.
+This document describes version 0.003 of File::Slurper::Temp (from Perl distribution File-Slurper-Temp), released on 2017-01-16.
 
 =head1 SYNOPSIS
 
